pub struct ShellLinkHeader { /* private fields */ }Expand description
A ShellLinkHeader structure (section 2.1), which contains identification information, timestamps, and flags that specify the presence of optional structures.
Implementations
Sourceimpl ShellLinkHeader
impl ShellLinkHeader
Sourcepub fn header_size(&self) -> &u32
pub fn header_size(&self) -> &u32
The size, in bytes, of this structure. This value MUST be 0x0000004C.
Sourcepub fn link_clsid(&self) -> &Guid
pub fn link_clsid(&self) -> &Guid
This value MUST be 00021401-0000-0000-C000-000000000046.
Sourcepub fn link_flags(&self) -> &LinkFlags
pub fn link_flags(&self) -> &LinkFlags
A LinkFlags structure (section 2.1.1) that specifies information about the shell link and the presence of optional portions of the structure.
Sourcepub fn file_attributes(&self) -> &FileAttributeFlags
pub fn file_attributes(&self) -> &FileAttributeFlags
A FileAttributesFlags structure (section 2.1.2) that specifies information about the link target.
Sourcepub fn creation_time(&self) -> &FileTime
pub fn creation_time(&self) -> &FileTime
A FILETIME structure ([MS-DTYP]section 2.3.3) that specifies the creation time of the link target in UTC (Coordinated Universal Time). If the value is zero, there is no creation time set on the link target.
Sourcepub fn access_time(&self) -> &FileTime
pub fn access_time(&self) -> &FileTime
A FILETIME structure ([MS-DTYP] section2.3.3) that specifies the access time of the link target in UTC (Coordinated Universal Time). If the value is zero, there is no access time set on the link target.
Sourcepub fn write_time(&self) -> &FileTime
pub fn write_time(&self) -> &FileTime
A FILETIME structure ([MS-DTYP] section 2.3.3) that specifies the write time of the link target in UTC (Coordinated Universal Time). If the value is zero, there is no write time set on the link target.
Sourcepub fn file_size(&self) -> &u32
pub fn file_size(&self) -> &u32
A 32-bit unsigned integer that specifies the size, in bytes, of the link target. If the link target fileis larger than 0xFFFFFFFF, this value specifies the least significant 32 bits of the link target file size.
Sourcepub fn icon_index(&self) -> &i32
pub fn icon_index(&self) -> &i32
A 32-bit signed integer that specifies the index of an icon within a given icon location.
Sourcepub fn show_command(&self) -> &ShowCommand
pub fn show_command(&self) -> &ShowCommand
A 32-bit unsigned integer that specifies the expected window state of an application launched by the link.
Sourcepub fn hotkey(&self) -> &HotkeyFlags
pub fn hotkey(&self) -> &HotkeyFlags
A HotkeyFlags structure (section 2.1.3) that specifies the keystrokes used to launch the application referenced by the shortcut key. This value is assigned to the application after it is launched, so that pressing the key activates that application.
Sourceimpl ShellLinkHeader
impl ShellLinkHeader
Sourcepub fn header_size_mut(&mut self) -> &mut u32
pub fn header_size_mut(&mut self) -> &mut u32
The size, in bytes, of this structure. This value MUST be 0x0000004C.
Sourcepub fn link_clsid_mut(&mut self) -> &mut Guid
pub fn link_clsid_mut(&mut self) -> &mut Guid
This value MUST be 00021401-0000-0000-C000-000000000046.
Sourcepub fn link_flags_mut(&mut self) -> &mut LinkFlags
pub fn link_flags_mut(&mut self) -> &mut LinkFlags
A LinkFlags structure (section 2.1.1) that specifies information about the shell link and the presence of optional portions of the structure.
Sourcepub fn file_attributes_mut(&mut self) -> &mut FileAttributeFlags
pub fn file_attributes_mut(&mut self) -> &mut FileAttributeFlags
A FileAttributesFlags structure (section 2.1.2) that specifies information about the link target.
Sourcepub fn creation_time_mut(&mut self) -> &mut FileTime
pub fn creation_time_mut(&mut self) -> &mut FileTime
A FILETIME structure ([MS-DTYP]section 2.3.3) that specifies the creation time of the link target in UTC (Coordinated Universal Time). If the value is zero, there is no creation time set on the link target.
Sourcepub fn access_time_mut(&mut self) -> &mut FileTime
pub fn access_time_mut(&mut self) -> &mut FileTime
A FILETIME structure ([MS-DTYP] section2.3.3) that specifies the access time of the link target in UTC (Coordinated Universal Time). If the value is zero, there is no access time set on the link target.
Sourcepub fn write_time_mut(&mut self) -> &mut FileTime
pub fn write_time_mut(&mut self) -> &mut FileTime
A FILETIME structure ([MS-DTYP] section 2.3.3) that specifies the write time of the link target in UTC (Coordinated Universal Time). If the value is zero, there is no write time set on the link target.
Sourcepub fn file_size_mut(&mut self) -> &mut u32
pub fn file_size_mut(&mut self) -> &mut u32
A 32-bit unsigned integer that specifies the size, in bytes, of the link target. If the link target fileis larger than 0xFFFFFFFF, this value specifies the least significant 32 bits of the link target file size.
Sourcepub fn icon_index_mut(&mut self) -> &mut i32
pub fn icon_index_mut(&mut self) -> &mut i32
A 32-bit signed integer that specifies the index of an icon within a given icon location.
Sourcepub fn show_command_mut(&mut self) -> &mut ShowCommand
pub fn show_command_mut(&mut self) -> &mut ShowCommand
A 32-bit unsigned integer that specifies the expected window state of an application launched by the link.
Sourcepub fn hotkey_mut(&mut self) -> &mut HotkeyFlags
pub fn hotkey_mut(&mut self) -> &mut HotkeyFlags
A HotkeyFlags structure (section 2.1.3) that specifies the keystrokes used to launch the application referenced by the shortcut key. This value is assigned to the application after it is launched, so that pressing the key activates that application.
Sourcepub fn reserved1_mut(&mut self) -> &mut u16
pub fn reserved1_mut(&mut self) -> &mut u16
A value that MUST be zero
Sourcepub fn reserved2_mut(&mut self) -> &mut u32
pub fn reserved2_mut(&mut self) -> &mut u32
A value that MUST be zero
Sourcepub fn reserved3_mut(&mut self) -> &mut u32
pub fn reserved3_mut(&mut self) -> &mut u32
A value that MUST be zero
Sourceimpl ShellLinkHeader
impl ShellLinkHeader
Sourcepub fn set_header_size(&mut self, val: u32) -> &mut Self
pub fn set_header_size(&mut self, val: u32) -> &mut Self
The size, in bytes, of this structure. This value MUST be 0x0000004C.
Sourcepub fn set_link_clsid(&mut self, val: Guid) -> &mut Self
pub fn set_link_clsid(&mut self, val: Guid) -> &mut Self
This value MUST be 00021401-0000-0000-C000-000000000046.
Sourcepub fn set_link_flags(&mut self, val: LinkFlags) -> &mut Self
pub fn set_link_flags(&mut self, val: LinkFlags) -> &mut Self
A LinkFlags structure (section 2.1.1) that specifies information about the shell link and the presence of optional portions of the structure.
Sourcepub fn set_file_attributes(&mut self, val: FileAttributeFlags) -> &mut Self
pub fn set_file_attributes(&mut self, val: FileAttributeFlags) -> &mut Self
A FileAttributesFlags structure (section 2.1.2) that specifies information about the link target.
Sourcepub fn set_creation_time(&mut self, val: FileTime) -> &mut Self
pub fn set_creation_time(&mut self, val: FileTime) -> &mut Self
A FILETIME structure ([MS-DTYP]section 2.3.3) that specifies the creation time of the link target in UTC (Coordinated Universal Time). If the value is zero, there is no creation time set on the link target.
Sourcepub fn set_access_time(&mut self, val: FileTime) -> &mut Self
pub fn set_access_time(&mut self, val: FileTime) -> &mut Self
A FILETIME structure ([MS-DTYP] section2.3.3) that specifies the access time of the link target in UTC (Coordinated Universal Time). If the value is zero, there is no access time set on the link target.
Sourcepub fn set_write_time(&mut self, val: FileTime) -> &mut Self
pub fn set_write_time(&mut self, val: FileTime) -> &mut Self
A FILETIME structure ([MS-DTYP] section 2.3.3) that specifies the write time of the link target in UTC (Coordinated Universal Time). If the value is zero, there is no write time set on the link target.
Sourcepub fn set_file_size(&mut self, val: u32) -> &mut Self
pub fn set_file_size(&mut self, val: u32) -> &mut Self
A 32-bit unsigned integer that specifies the size, in bytes, of the link target. If the link target fileis larger than 0xFFFFFFFF, this value specifies the least significant 32 bits of the link target file size.
Sourcepub fn set_icon_index(&mut self, val: i32) -> &mut Self
pub fn set_icon_index(&mut self, val: i32) -> &mut Self
A 32-bit signed integer that specifies the index of an icon within a given icon location.
Sourcepub fn set_show_command(&mut self, val: ShowCommand) -> &mut Self
pub fn set_show_command(&mut self, val: ShowCommand) -> &mut Self
A 32-bit unsigned integer that specifies the expected window state of an application launched by the link.
Sourcepub fn set_hotkey(&mut self, val: HotkeyFlags) -> &mut Self
pub fn set_hotkey(&mut self, val: HotkeyFlags) -> &mut Self
A HotkeyFlags structure (section 2.1.3) that specifies the keystrokes used to launch the application referenced by the shortcut key. This value is assigned to the application after it is launched, so that pressing the key activates that application.
Sourcepub fn set_reserved1(&mut self, val: u16) -> &mut Self
pub fn set_reserved1(&mut self, val: u16) -> &mut Self
A value that MUST be zero
Sourcepub fn set_reserved2(&mut self, val: u32) -> &mut Self
pub fn set_reserved2(&mut self, val: u32) -> &mut Self
A value that MUST be zero
Sourcepub fn set_reserved3(&mut self, val: u32) -> &mut Self
pub fn set_reserved3(&mut self, val: u32) -> &mut Self
A value that MUST be zero
Sourceimpl ShellLinkHeader
impl ShellLinkHeader
Sourcepub fn update_link_flags(&mut self, link_flags: LinkFlags, value: bool)
pub fn update_link_flags(&mut self, link_flags: LinkFlags, value: bool)
Set some link flags